@@ -23,9 +23,14 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <ags/config.h>
+
+#ifdef AGS_WITH_PULSE
 #include <pulse/pulseaudio.h>
 #include <pulse/stream.h>
 #include <pulse/error.h>
+#include <pulse/glib-mainloop.h>
+#endif
 
 #include <pthread.h>
 
@@ -57,8 +62,13 @@ struct _AgsPulseServer
   
   GObject *application_context;
 
-  pa_mainloop *main_loop;
+#ifdef AGS_WITH_PULSE
+  pa_glib_mainloop *main_loop;
   pa_mainloop_api *main_loop_api;
+#else
+  gpointer main_loop;
+  gpointer main_loop_api;
+#endif
   
   gchar *url;
 
